@@ -110,9 +110,9 @@
 ;;
 ;;  When running `mode-compile' or `mode-compile-kill' the hooks
 ;;  `mode-compile-(before|after)-(compile|kill)-hook' are executed.
-;;  The current buffer could be automaticaly saved if variable
+;;  The current buffer could be automatically saved if variable
 ;;  `mode-compile-always-save-buffer-p' is set to `t'.  ALL the
-;;  modified buffers could be automaticaly saved if variable
+;;  modified buffers could be automatically saved if variable
 ;;  `mode-compile-save-all-p' is set to `t'.
 ;;
 ;; @@ fundamental-mode, text-mode, indented-text-mode & UNKNOWN MODES:
@@ -411,7 +411,7 @@ To add a new filename regexp do the following:
             (regexp :tag "Regexp as a string")
             (symbol :tag "Variable containing the regexp")
             (sexp :tag "Form wich evaluate to a string"))
-           ;; I need to bind dynamicaly this with const, ideas??
+           ;; I need to bind dynamically this with const, ideas??
            ;;`(choice
            ;; ,@(mapcar (lambda (x) `(const ,(car x))) mode-compile-modes-alist))))
            (function :tag "Mode to use -- should be a valid assoq in mode-compile-modes-alist --")))
@@ -440,7 +440,7 @@ To add a new shell do the following:
   :type '(repeat
           (cons :tag "Association: shell name/mode"
            (string :tag "Shell name")
-           ;; I need to bind dynamicaly this with const, ideas??
+           ;; I need to bind dynamically this with const, ideas??
            ;;`(choice
            ;; ,@(mapcar (lambda (x) `(const ,(car x))) mode-compile-modes-alist))))
            (function :tag "Mode to use -- should be a valid assoq in mode-compile-modes-alist --")))
@@ -642,7 +642,7 @@ which will be used for compiling without makefile.
 
  Could be used in combination with
  (cc|c++|ada|f77)-default-compiler-options
-to automaticaly choose the compiler specific options.
+to automatically choose the compiler specific options.
 
 example:
  (defun my-compiler-get-options()
@@ -708,7 +708,7 @@ user-login-name will be used."
   "The shell command used to run a command remotely.
 \"rsh\" is the only choice I know but I'm far to know everything...
 
- This variable is set automaticaly with the value of
+ This variable is set automatically with the value of
 remote-shell-program or efs-remote-shell-file-name at load time."
   :type 'string
   :group 'compilation)
@@ -748,7 +748,7 @@ on the remote host, to give to mode-compile-remote-execute-command."
   :group 'compilation-remote)
 
 (defcustom mode-compile-remote-execute-misc-args ""
-  "Misc additionnals arguments to give to the
+  "Misc additional arguments to give to the
 mode-compile-remote-execute-command."
   :type 'string
   :group 'compilation-remote)
